@@ -48,6 +48,7 @@ from ..models import (
     EndpointSecretOut,
     EndpointSecretRotateIn,
     EndpointStats,
+    EndpointTransformationIn,
     EndpointTransformationOut,
     EndpointTransformationPatch,
     EndpointUpdate,
@@ -345,6 +346,7 @@ __all__ = [
     "EndpointSecretOut",
     "EndpointSecretRotateIn",
     "EndpointStats",
+    "EndpointTransformationIn",
     "EndpointTransformationOut",
     "EndpointTransformationPatch",
     "EndpointUpdate",
